@@ -4,7 +4,7 @@ use strict;
 use warnings FATAL => 'all';
 use Module::Runtime qw[ require_module ];
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 $VERSION = eval $VERSION;
 
 #For instances when you want to use s3, but don't want to install anything. ( and you have curl )
@@ -178,7 +178,7 @@ Amazon::S3Curl::PurePerl - Pure Perl s3 helper/downloader.
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -270,7 +270,7 @@ Delete url.
 
 Just get the command to execute, don't actually execute it:
     my $cmd = $s3curl->download_cmd;
-    `$cmd`;
+    system(@$cmd);
 
 =head1 LICENSE
 
